@@ -1,6 +1,7 @@
 # coding=utf-8
 import json
 import logging
+import re
 import sys
 import uuid
 from datetime import datetime
@@ -30,6 +31,7 @@ _current_framework = None
 _logger = get_library_logger(__name__)
 _request_util = None
 _default_formatter = None
+_exclude_URL_patterns = []
 
 
 def get_correlation_id(request=None):
@@ -152,7 +154,7 @@ def __init(framework_name=None, custom_formatter=None, enable_json=False):
     util.update_formatter_for_loggers(existing_loggers, _default_formatter)
 
 
-def init_request_instrument(app=None, custom_formatter=None):
+def init_request_instrument(app=None, custom_formatter=None, exclude_url_patterns=[]):
     """
     Configure the request instrumentation logging configuration for given web app. Must be called after init method
 
@@ -169,8 +171,10 @@ def init_request_instrument(app=None, custom_formatter=None):
         if not issubclass(custom_formatter, logging.Formatter):
             raise ValueError('custom_formatter is not subclass of logging.Formatter', custom_formatter)
 
+    global _exclude_URL_patterns
+    _exclude_URL_patterns = exclude_url_patterns
     configurator = _current_framework['app_request_instrumentation_configurator']()
-    configurator.config(app)
+    configurator.config(app, exclude_url_patterns=exclude_url_patterns)
 
     formatter = custom_formatter if custom_formatter else JSONRequestLogFormatter
     request_logger = configurator.request_logger
@@ -261,13 +265,13 @@ class JSONRequestLogFormatter(BaseJSONFormatter):
         json_log_object = super(JSONRequestLogFormatter, self)._format_log_object(record, request_util)
         request = record.request_info.request
         request_adapter = request_util.request_adapter
-
+        path = request_adapter.get_path(request)
         length = request_adapter.get_content_length(request)
         json_log_object.update({
             "type": "request",
             "correlation_id": request_util.get_correlation_id(request),
             "remote_user": request_adapter.get_remote_user(request),
-            "request": request_adapter.get_path(request),
+            "request": path,
             "referer": request_adapter.get_http_header(request, 'referer', EMPTY_VALUE),
             "x_forwarded_for": request_adapter.get_http_header(request, 'x-forwarded-for', EMPTY_VALUE),
             "protocol": request_adapter.get_protocol(request),
